==> apache-camel-3.14.2-src.zip: apache-camel-3.14.2/components/camel-saxon/src/test/java/org/apache/camel/component/xslt/extensions/SaxonLanguageExtensionFunctionsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xslt.extensions;

import net.sf.saxon.Configuration;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.component.xquery.XQueryWithExtensionTest;
import org.apache.camel.language.xquery.XQueryLanguage;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

public class SaxonLanguageExtensionFunctionsTest extends CamelTestSupport {

    @Test
    public void testWithExtension() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("<transformed extension-function-render=\"arg1[test]\"/>");

        template.sendBody("direct:start", "<body>test</body>");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                Configuration conf = new Configuration();
                conf.registerExtensionFunction(new XQueryWithExtensionTest.SimpleExtension());

                XQueryLanguage xq = (XQueryLanguage) context.resolveLanguage("xquery");
                xq.setConfiguration(conf);

                from("direct:start")
                        .transform()
                        .xquery("resource:classpath:org/apache/camel/component/xquery/transformWithExtension.xquery")
                        .to("mock:result");
            }
        };
    }
}

==> apache-camel-3.18.5-src.zip: apache-camel-3.18.5/components/camel-saxon/src/test/java/org/apache/camel/component/xslt/extensions/SaxonLanguageExtensionFunctionsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xslt.extensions;

import net.sf.saxon.Configuration;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.component.xquery.XQueryWithExtensionTest;
import org.apache.camel.language.xquery.XQueryLanguage;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

public class SaxonLanguageExtensionFunctionsTest extends CamelTestSupport {

    @Test
    public void testWithExtension() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("<transformed extension-function-render=\"arg1[test]\"/>");

        template.sendBody("direct:start", "<body>test</body>");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                Configuration conf = new Configuration();
                conf.registerExtensionFunction(new XQueryWithExtensionTest.SimpleExtension());

                XQueryLanguage xq = (XQueryLanguage) context.resolveLanguage("xquery");
                xq.setConfiguration(conf);

                from("direct:start")
                        .transform()
                        .xquery("resource:classpath:org/apache/camel/component/xquery/transformWithExtension.xquery")
                        .to("mock:result");
            }
        };
    }
}
